@@ -54,12 +36,12 @@
-
+
is_active == 0) { ?>
-
+
diff --git a/assets/default/customize/style.css b/assets/default/customize/style.css
new file mode 100644
index 0000000..810d646
--- /dev/null
+++ b/assets/default/customize/style.css
@@ -0,0 +1,101 @@
+/* file name =>user/change_password.php and user/add_user.php */
+.field-icon {
+ float: right;
+ margin-left: -25px;
+ margin-top: -25px;
+ margin-right: 10px;
+ position: relative;
+ z-index: 3;
+}
+
+
+
+/* file name =>user/profile.php */
+.fa-plus {
+ float: right;
+ margin-left: -25px;
+ margin-top: -70px;
+ margin-right: 10px;
+ position: relative;
+ z-index: 3;
+ font-size: 30px;
+}
+/* profile pic */
+body {
+ font-family: sans-serif;
+}
+
+.profilepic {
+ position: relative;
+ /* width: 125px;
+ height: 125px; */
+ /* border-radius: 50%; */
+ overflow: hidden;
+ background-color: #fffff7;
+}
+
+.profilepic:hover .profilepic__content {
+ opacity: 1;
+}
+
+.profilepic:hover .profilepic__image {
+ opacity: .5;
+}
+
+.profilepic__image {
+ object-fit: cover;
+ opacity: 1;
+ transition: opacity .2s ease-in-out;
+}
+
+.profilepic__content {
+ position: absolute;
+ top: 0;
+ right: 0;
+ bottom: 0;
+ left: 0;
+ display: flex;
+ flex-direction: column;
+ justify-content: center;
+ align-items: center;
+ color: black;
+ opacity: 0;
+ transition: opacity .2s ease-in-out;
+}
+
+.profilepic__icon {
+ color: white;
+ padding-bottom: 8px;
+}
+
+.fas {
+ font-size: 20px;
+}
+
+.profilepic__text {
+ text-transform: uppercase;
+ font-size: 12px;
+ width: 50%;
+ text-align: center;
+}
+
+
+
+/* file name =>user/user_list.php */
+.btn.active {
+ display: none;
+}
+
+.btn span:nth-of-type(1) {
+ display: none;
+}
+.btn span:last-child {
+ display: block;
+}
+
+.btn.active span:nth-of-type(1) {
+ display: block;
+}
+.btn.active span:last-child {
+ display: none;
+}
diff --git a/assets/default/customize/ajax.js b/assets/default/customize/ajax.js
index a7cb10e..8189f5c 100644
--- a/assets/default/customize/ajax.js
+++ b/assets/default/customize/ajax.js
@@ -149,8 +149,21 @@ $( document ).ready(function() {
});
-// ------------------------------------------------------
-
+
+
+
+
+
+// ################################################################################################################################
+
+
+
+
+
+
+
+
+// show error msg for wrong password => file name : user/change_password.php
$(document).on('click','#submit',function(){
var data = $("#change-pass").serialize();
$.ajax({
@@ -163,42 +176,24 @@ $(document).on('click','#submit',function(){
// location.href = "auth";
}
else {
- $('#message1').html('Worng password').css('color', 'red');
- alert(response);
+ $('#message1').html('Worng password').css('color', 'red');
+ $('#password').val('');
+ $('#confirm_password').val('');
+ $('#message').html('');
}
},
error: function(jqXHR, textStatus, err) { alert('text status '+textStatus+', err '+err) }
});
- });
-
-
- // match the password and confirm password equal or not
- $('#password, #confirm_password').on('keyup', function () {
- $(':input[type="submit"]').prop('disabled', true);
- if ($('#password').val() == $('#confirm_password').val() && $('#confirm_password').val().length > 0 ) {
- $('#message').html('Matching').css('color', 'green');
- $('button[type="submit"]').attr("disabled", false);
- }
- else if($('#password').val().length == 0 || $('#confirm_password').val().length == 0){
- $('#message').html('');
- }
- else
- $('#message').html('Not Matching').css('color', 'red');
- });
-
- // password eye icon
- $(".toggle-password").click(function() {
- $(this).toggleClass("fa-eye fa-eye-slash");
- var input = $($(this).attr("toggle"));
- if (input.attr("type") == "password") {
- input.attr("type", "text");
- }
- else {
- input.attr("type", "password");
- }
- });
+});
- // match the password and confirm password equal or not
+// hide err msg when the input is empty => file name : user/change_password.php , label name : Old Password
+$('#old_password').on('keyup', function () {
+ if($('#old_password').val().length == 0){
+ $('#message1').html('');
+ }
+});
+
+// match the password and confirm password equal or not => file name : user/change_password.php and user/add_user.php
$('#password, #confirm_password').on('keyup', function () {
$(':input[type="submit"]').prop('disabled', true);
if ($('#password').val() == $('#confirm_password').val() && $('#confirm_password').val().length > 0 ) {
@@ -210,10 +205,10 @@ $('#password, #confirm_password').on('keyup', function () {
}
else
$('#message').html('Not Matching').css('color', 'red');
- });
+});
- // password eye icon
- $(".toggle-password").click(function() {
+// password eye icon => file name : user/add_user.php && user/change_password.php
+$("#toggle-password").click(function() {
$(this).toggleClass("fa-eye fa-eye-slash");
var input = $($(this).attr("toggle"));
if (input.attr("type") == "password") {
@@ -222,10 +217,10 @@ $('#password, #confirm_password').on('keyup', function () {
else {
input.attr("type", "password");
}
- });
+});
- // sadmin create admin onchange function select permit as all default
- $('#role').on('change', function() {
+// sadmin create admin onchange function select permit as all default => file name : user/add_user.php
+$('#role').on('change', function() {
if(this.value == "admin")
{
$('#action_permit').html('
');
@@ -238,4 +233,26 @@ $('#password, #confirm_password').on('keyup', function () {
`);
}
- });
\ No newline at end of file
+});
+
+// file open => file name : user/profile.php
+// The handler is executed at most once per element per event type => one()
+$(".profilepic").one('click',function() {
+ $("#file_profile").trigger("click");
+});
+
+// $(".profilepic").click(function(){
+// console.log("aaaa");
+// // $("#file_profile").trigger("click");
+// });
+
+// change login person profile pic => file name : user/profile.php
+$(document).ready(function(){
+$("#file_profile").change(function(){
+ $(".btn-success").click();
+});
+});
+
+
+
+
diff --git a/assets/uploads/logo/company-logo.png b/assets/uploads/logo/company-logo.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/logo/company-logo.png differ
diff --git a/assets/uploads/logo/company-logo1.png b/assets/uploads/logo/company-logo1.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/logo/company-logo1.png differ
diff --git a/assets/uploads/profile_picture/Screenshot_(237)11.png b/assets/uploads/profile_picture/Screenshot_(237)11.png
new file mode 100644
index 0000000..d311229
Binary files /dev/null and b/assets/uploads/profile_picture/Screenshot_(237)11.png differ
diff --git a/assets/uploads/profile_picture/Screenshot_(237)2.png b/assets/uploads/profile_picture/Screenshot_(237)2.png
new file mode 100644
index 0000000..d311229
Binary files /dev/null and b/assets/uploads/profile_picture/Screenshot_(237)2.png differ
diff --git a/assets/uploads/profile_picture/Screenshot_(237)21.png b/assets/uploads/profile_picture/Screenshot_(237)21.png
new file mode 100644
index 0000000..d311229
Binary files /dev/null and b/assets/uploads/profile_picture/Screenshot_(237)21.png differ
diff --git a/assets/uploads/profile_picture/company-logo.png b/assets/uploads/profile_picture/company-logo.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo.png differ
diff --git a/assets/uploads/profile_picture/company-logo1.png b/assets/uploads/profile_picture/company-logo1.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo1.png differ
diff --git a/assets/uploads/profile_picture/company-logo11.png b/assets/uploads/profile_picture/company-logo11.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo11.png differ
diff --git a/assets/uploads/profile_picture/company-logo12.png b/assets/uploads/profile_picture/company-logo12.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo12.png differ
diff --git a/assets/uploads/profile_picture/company-logo121.png b/assets/uploads/profile_picture/company-logo121.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo121.png differ
diff --git a/assets/uploads/profile_picture/company-logo122.png b/assets/uploads/profile_picture/company-logo122.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo122.png differ
diff --git a/assets/uploads/profile_picture/company-logo13.png b/assets/uploads/profile_picture/company-logo13.png
new file mode 100644
index 0000000..dd539c9
Binary files /dev/null and b/assets/uploads/profile_picture/company-logo13.png differ
diff --git a/assets/uploads/profile_picture/profile10.jpg b/assets/uploads/profile_picture/profile10.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile10.jpg differ
diff --git a/assets/uploads/profile_picture/profile11.jpg b/assets/uploads/profile_picture/profile11.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile11.jpg differ
diff --git a/assets/uploads/profile_picture/profile12.jpg b/assets/uploads/profile_picture/profile12.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile12.jpg differ
diff --git a/assets/uploads/profile_picture/profile31.jpg b/assets/uploads/profile_picture/profile31.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile31.jpg differ
diff --git a/assets/uploads/profile_picture/profile41.jpg b/assets/uploads/profile_picture/profile41.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile41.jpg differ
diff --git a/assets/uploads/profile_picture/profile5.jpg b/assets/uploads/profile_picture/profile5.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile5.jpg differ
diff --git a/assets/uploads/profile_picture/profile6.jpg b/assets/uploads/profile_picture/profile6.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile6.jpg differ
diff --git a/assets/uploads/profile_picture/profile7.jpg b/assets/uploads/profile_picture/profile7.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile7.jpg differ
diff --git a/assets/uploads/profile_picture/profile8.jpg b/assets/uploads/profile_picture/profile8.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile8.jpg differ
diff --git a/assets/uploads/profile_picture/profile9.jpg b/assets/uploads/profile_picture/profile9.jpg
new file mode 100644
index 0000000..8d4863a
Binary files /dev/null and b/assets/uploads/profile_picture/profile9.jpg differ
diff --git a/assets/uploads/profile_picture/venba-information-technology1.png b/assets/uploads/profile_picture/venba-information-technology1.png
new file mode 100644
index 0000000..bf6a47e
Binary files /dev/null and b/assets/uploads/profile_picture/venba-information-technology1.png differ